@@ -1,5 +1,6 @@
 from AppiumLibrary import AppiumLibrary
 from airtest.core.settings import Settings as ST
+from airobots.core.api import G
 import allure
 
 
@@ -11,7 +12,9 @@ class AirAppium(AppiumLibrary):
 
     @allure.step
     def open_application(self, remote_url=ST.REMOTE_URL, alias=None, **kwargs):
-        return super(AirAppium, self).open_application(remote_url=remote_url, alias=alias, **kwargs)
+        app = super(AirAppium, self).open_application(remote_url=remote_url, alias=alias, **kwargs)
+        G.add_device(self._current_application())
+        return app
 
     @allure.step
     def close_application(self):
@@ -125,6 +128,38 @@ class AirAppium(AppiumLibrary):
     def page_should_not_contain_text(self, text, loglevel='INFO'):
         return super(AirAppium, self).page_should_not_contain_text(text=text, loglevel=loglevel)
 
+    @allure.step
+    def text_should_be_visible(self, text, exact_match=False, loglevel='INFO'):
+        return super(AirAppium, self).text_should_be_visible(text=text, exact_match=exact_match, loglevel=loglevel)
+
+    @allure.step
+    def element_text_should_be(self, locator, expected, message=''):
+        return super(AirAppium, self).element_text_should_be(locator=locator, expected=expected, message=message)
+
+    @allure.step
+    def element_value_should_be(self, locator, expected):
+        return super(AirAppium, self).element_value_should_be(locator=locator, expected=expected)
+
+    @allure.step
+    def element_should_be_visible(self, locator, loglevel='INFO'):
+        return super(AirAppium, self).element_should_be_visible(locator=locator, loglevel=loglevel)
+
+    @allure.step
+    def element_should_be_enabled(self, locator, loglevel='INFO'):
+        return super(AirAppium, self).element_should_be_enabled(locator=locator, loglevel=loglevel)
+
+    @allure.step
+    def element_should_be_disabled(self, locator, loglevel='INFO'):
+        return super(AirAppium, self).element_should_be_disabled(locator=locator, loglevel=loglevel)
+
+    @allure.step
+    def element_should_not_contain_text(self, locator, expected, message=''):
+        return super(AirAppium, self).element_should_not_contain_text(locator=locator, expected=expected, message=message)
+
+    @allure.step
+    def element_should_contain_text(self, locator, expected, message=''):
+        return super(AirAppium, self).element_should_contain_text(locator=locator, expected=expected, message=message)
+
     def capture_page_screenshot(self, filename=None):
         file = super(AirAppium, self).capture_page_screenshot(filename=filename)
         with open(file, 'rb') as fp:
